@@ -37,7 +37,9 @@ public class CreateGraphGUI extends JFrame implements WindowListener {
 		JComponent.setDefaultLocale(Locale.US); 
 		RControl.getRControl(debug);
 		Localizer.getInstance().addResourceBundle("org.mutoss.gui.ResourceBundle");
-		Configuration.getInstance().getGeneralConfig().setGridSize((int)grid);
+		if (grid>0) {
+			Configuration.getInstance().getGeneralConfig().setGridSize((int)grid);
+		}
 		setIconImage((new ImageIcon(getClass().getResource("/org/mutoss/gui/graph/images/rjavaicon64.png"))).getImage());
 		
 		// Fenster in der Mitte des Bildschirms platzieren mit inset = 50 Pixeln Rand.
@@ -86,7 +88,7 @@ public class CreateGraphGUI extends JFrame implements WindowListener {
 	}
 
 	public static void main(String[] args) {
-		new CreateGraphGUI("graph", new double[] {}, true, 10);
+		new CreateGraphGUI("graph", new double[] {}, true,  10);
 	}
 
 	public void windowActivated(WindowEvent e) {}
